(function (Drupal, cookies) {

  'use strict';

  Drupal.behaviors.emergency_notification = {

    runTimes: 1,

    /**
     * Attach method for this behavior.
     *
     * @param {object} context
     *   The context for which the behavior is being executed. This is either
     *   the full page or a piece of HTML that was just added through Ajax.
     * @param {object} settings
     *   An array of settings (added through drupal_add_js()). Instead of
     *   accessing Drupal.settings directly you should use this because of
     *   potential modifications made by the Ajax callback that also produced
     *   'context'.
     */
    attach: function (context, settings) {
      const self = this;

      if (self.runTimes && typeof settings.emergency_notification_settings !== 'undefined') {
        const en_settings = settings.emergency_notification_settings;

        if (
          typeof en_settings.enable_notification !== 'undefined' &&
          en_settings.enable_notification
        ) {
          self.setCookies(en_settings);
          self.dismissPopup();
          self.togglePopup();
        }

        self.runTimes--;
      }
    },

    /**
     * Settings emergency notification cookies.
     *
     * @param {object} en_settings
     *   An array of emergency notification settings.
     */
    setCookies: function (en_settings) {
      if (
        typeof en_settings.form_submission !== 'undefined' &&
        en_settings.form_submission !== cookies.get('emergency_notification_id')
      ) {
        cookies.set('emergency_notification_dismiss', 0);
        cookies.set('emergency_notification_id', en_settings.form_submission);
      }
    },

    /**
     * Dismisses emergency notification.
     *
     * @param {object} context
     *   The context for which the behavior is being executed. This is either
     *   the full page or a piece of HTML that was just added through Ajax.
     */
    dismissPopup: function () {
      const self = this;

      document.querySelector('#emergency-popup-wrapper .dismiss-btn').addEventListener('click', () => {

        if (cookies.get('emergency_notification_dismiss') === '0') {
          const emergancyNotice = document.getElementById('emergency-notification');

          emergancyNotice.classList.remove('open-popup');
          emergancyNotice.classList.add('dismissed');

          cookies.set('emergency_notification_dismiss', 1);
        }
        else {
          self.slideToggle();
        }
      });
    },

    /**
     * Adds JS functionality for toggling emergency notification.
     */
    togglePopup: function () {
      const self = this;

      if (cookies.get('emergency_notification_dismiss') === '0') {
        const emergancyNotice = document.getElementById('emergency-notification');

        emergancyNotice.classList.add('open-popup');
        emergancyNotice.classList.remove('dismissed');
      }

      document.querySelector('#emergency-popup-wrapper .open-btn').addEventListener('click', (e) => {

        // Slide toggle.
        self.slideToggle();
      });
    },

    /**
     * Toggle slides
     */
    slideToggle: function () {
      const popup = document.querySelector('#emergency-popup-wrapper .emergency-popup');

      if (!popup.classList.contains('active')) {
        popup.classList.add('active');
        popup.style.height = 'auto';

        const height = popup.clientHeight + 'px';
        popup.style.height = '0px';

        setTimeout(function () {
          popup.style.height = height;
        }, 0);
      } else {
        popup.style.height = '0px';

        popup.addEventListener('transitionend', () => {
          popup.classList.remove('active');
        }, {
          once: true
        });
      }
    }

  };
})(Drupal, window.Cookies);
